Notitie
Voor toegang tot deze pagina is autorisatie vereist. U kunt proberen u aan te melden of de directory te wijzigen.
Voor toegang tot deze pagina is autorisatie vereist. U kunt proberen de mappen te wijzigen.
In dit artikel worden de rest API-bewerkingen voor het genereren van afbeeldingen, audio (spraak) en videogeneratie voor Azure OpenAI in de preview-versie van v1 beschreven. Zie de officiële Azure OpenAI REST API-verwijzing voor voltooiingen, insluitingen, evals, bestanden, afstemming, antwoorden, vectorarchieven en alle andere bewerkingen.
Deductie van het gegevensvlak
In de rest van dit artikel worden de afbeeldings-, audio- en videobewerkingen beschreven in de nieuwe versie van de v1 preview-API van de specificatie van de Azure OpenAI-gegevensvlakdeductie. Zie de handleiding voor de API-levenscyclus voor meer informatie.
Zie de officiële Azure OpenAI REST API-verwijzing voor de volledige V1 GA-gegevensvlak-API.
Spraak maken
POST {endpoint}/openai/v1/audio/speech?api-version=preview
Hiermee genereert u tekst-naar-spraak-audio van de invoertekst.
URI-parameters
| Naam | In | Required | Type | Description |
|---|---|---|---|---|
| endpoint | path | Ja | tekenreeks URL |
Ondersteunde Azure OpenAI-eindpunten (protocol en hostnaam, bijvoorbeeld: https://aoairesource.openai.azure.com. Vervang 'aoairesource' door uw Azure OpenAI-resourcenaam). https://{your-resource-name}.openai.azure.com |
| api-versie | zoekopdracht | No | De expliciete Microsoft Foundry Models API-versie die voor deze aanvraag moet worden gebruikt.v1 als dit niet anders is opgegeven. |
Koptekst van aanvraag
Gebruik verificatie op basis van tokens of API-sleutel. Verificatie met verificatie op basis van tokens wordt aanbevolen en veiliger.
| Naam | Required | Type | Description |
|---|---|---|---|
| Autorisatie | True | tekenreeks |
Voorbeeld:Authorization: Bearer {Azure_OpenAI_Auth_Token}To genereer een verificatietoken met behulp van Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comType: oauth2 Autorisatie-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeScope: https://ai.azure.com/.default |
| API-sleutel | True | tekenreeks | Geef hier Azure OpenAI API-sleutel op |
Aanvraaglichaam
Inhoudstype: multipart/form-data
| Naam | Type | Description | Required | Default |
|---|---|---|---|---|
| Invoer | tekenreeks | De tekst voor het genereren van audio. De maximumlengte is 4096 tekens. | Ja | |
| aanwijzingen | tekenreeks | Beheer de stem van uw gegenereerde audio met aanvullende instructies. Werkt niet met tts-1 of tts-1-hd. |
No | |
| model | tekenreeks | Het model dat moet worden gebruikt voor deze tekst-naar-spraak-aanvraag. | Ja | |
| responsformaat | Object | De ondersteunde audio-uitvoerindelingen voor tekst-naar-spraak. | No | |
| speed | number | De snelheid van spraak voor gegenereerde audio. Waarden zijn geldig in het bereik van 0,25 tot 4.0, waarbij 1,0 de standaardwaarden en hogere waarden overeenkomen met snellere spraak. | No | 1 |
| stream_format | enum | De indeling waarin de audio moet worden gestreamd. Ondersteunde indelingen zijn sse en audio.
sse wordt niet ondersteund voor tts-1 of tts-1-hd.Mogelijke waarden: sse, audio |
No | |
| voice | Object | Ja |
Responses
Statuscode: 200
Beschrijving: De aanvraag is geslaagd.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/octet-stream | tekenreeks |
Statuscode: standaard
Beschrijving: Een onverwachte foutreactie.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureErrorResponse |
Voorbeelden
Voorbeeld
Synthetiseert audio van de opgegeven tekst.
POST {endpoint}/openai/v1/audio/speech?api-version=preview
{
"input": "Hi! What are you going to make?",
"voice": "fable",
"response_format": "mp3",
"model": "tts-1"
}
Antwoorden: Statuscode: 200
{
"body": "101010101"
}
Transcriptie maken
POST {endpoint}/openai/v1/audio/transcriptions?api-version=preview
Hiermee wordt audio getranscribeerd in de invoertaal.
URI-parameters
| Naam | In | Required | Type | Description |
|---|---|---|---|---|
| endpoint | path | Ja | tekenreeks URL |
Ondersteunde Azure OpenAI-eindpunten (protocol en hostnaam, bijvoorbeeld: https://aoairesource.openai.azure.com. Vervang 'aoairesource' door uw Azure OpenAI-resourcenaam). https://{your-resource-name}.openai.azure.com |
| api-versie | zoekopdracht | No | De expliciete Foundry Models API-versie die voor deze aanvraag moet worden gebruikt.v1 als dit niet anders is opgegeven. |
Koptekst van aanvraag
Gebruik verificatie op basis van tokens of API-sleutel. Verificatie met verificatie op basis van tokens wordt aanbevolen en veiliger.
| Naam | Required | Type | Description |
|---|---|---|---|
| Autorisatie | True | tekenreeks |
Voorbeeld:Authorization: Bearer {Azure_OpenAI_Auth_Token}To genereer een verificatietoken met behulp van Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comType: oauth2 Autorisatie-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeScope: https://ai.azure.com/.default |
| API-sleutel | True | tekenreeks | Geef hier Azure OpenAI API-sleutel op |
Aanvraaglichaam
Inhoudstype: multipart/form-data
| Naam | Type | Description | Required | Default |
|---|---|---|---|---|
| chunking_strategy | Object | No | ||
| └prefix_padding_ms | integer | De hoeveelheid audio die moet worden opgenomen vóór de gedetecteerde VAD-spraak (in milliseconden). | No | 300 |
| └silence_duration_ms | integer | Duur van stilte om spraakstop te detecteren (in milliseconden). Met kortere waarden reageert het model sneller, maar kan het inspringen op korte pauzes van de gebruiker. | No | 200 |
| └─ drempelwaarde | number | Gevoeligheidsdrempel (0,0 tot 1.0) voor spraakactiviteitsdetectie. Voor een hogere drempelwaarde is luider geluid nodig om het model te activeren en kan het dus beter presteren in luidruchtige omgevingen. | No | 0,5 |
| └type. | enum | Moet zijn ingesteld om handmatig segmenteren in te server_vad schakelen met behulp van VAD aan de serverzijde.Mogelijke waarden: server_vad |
No | |
| bestand | tekenreeks | Ja | ||
| filename | tekenreeks | De optionele bestandsnaam of beschrijvende id die moet worden gekoppeld aan de audiogegevens. | No | |
| include[] | gegevensreeks | Aanvullende informatie die moet worden opgenomen in het transcriptieantwoord.
logprobs retourneert de logboekkans van de tokens in het antwoord om inzicht te krijgen in het vertrouwen van het model in de transcriptie.
logprobswerkt alleen met response_format ingesteld op json en alleen met de modellen gpt-4o-transcribe, gpt-4o-transcribe-diarizeen gpt-4o-mini-transcribegpt-4o-mini-transcribe-2025-12-15. |
No | |
| language | tekenreeks | De taal van de invoeraudio. Het leveren van de invoertaal in ISO-639-1 -indeling (bijvoorbeeld en) verbetert de nauwkeurigheid en latentie. |
No | |
| model | tekenreeks | Het model dat moet worden gebruikt voor deze transcriptieaanvraag. | No | |
| prompt | tekenreeks | Een optionele tekst om de stijl van het model te begeleiden of door te gaan met een vorig audiosegment. De prompt moet overeenkomen met de audiotaal. | No | |
| responsformaat | Object | No | ||
| stream | boolean | Als deze optie is ingesteld op true, worden de antwoordgegevens van het model naar de client gestreamd terwijl deze worden gegenereerd met behulp van door de server verzonden gebeurtenissen. Opmerking: Streaming wordt niet ondersteund voor het whisper-1 model en wordt genegeerd. |
No | Onwaar |
| Temperatuur | number | De steekproeftemperatuur, tussen 0 en 1. Hogere waarden zoals 0,8 zorgen ervoor dat de uitvoer willekeuriger wordt, terwijl lagere waarden zoals 0,2 ervoor zorgen dat de uitvoer meer gericht en deterministisch wordt. Als dit is ingesteld op 0, gebruikt het model logboekkans om de temperatuur automatisch te verhogen totdat bepaalde drempelwaarden worden bereikt. | No | 0 |
| timestamp_granularities[] | gegevensreeks | De tijdstempelgranulariteiten die moeten worden ingevuld voor deze transcriptie.
response_format moet worden ingesteld verbose_json op het gebruik van tijdstempelgranulariteiten. Of beide van deze opties worden ondersteund: word, of segment. Opmerking: er is geen extra latentie voor segmenttijdstempels, maar het genereren van woordtijdstempels zorgt voor extra latentie. |
No | ['segment'] |
Responses
Statuscode: 200
Beschrijving: De aanvraag is geslaagd.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureAudioTranscriptionResponse | |
| text/plain | tekenreeks |
Statuscode: standaard
Beschrijving: Een onverwachte foutreactie.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureErrorResponse |
Voorbeelden
Voorbeeld
Hiermee haalt u getranscribeerde tekst en bijbehorende metagegevens op uit de verstrekte gesproken audiogegevens.
POST {endpoint}/openai/v1/audio/transcriptions?api-version=preview
{
"file": "<binary audio data>",
"model": "whisper-1",
"response_format": "text"
}
Antwoorden: Statuscode: 200
{
"body": "plain text when requesting text, srt, or vtt"
}
Vertaling maken
POST {endpoint}/openai/v1/audio/translations?api-version=preview
Hiermee haalt u getranscribeerde engelse tekst en bijbehorende metagegevens op van opgegeven gesproken audiogegevens.
URI-parameters
| Naam | In | Required | Type | Description |
|---|---|---|---|---|
| endpoint | path | Ja | tekenreeks URL |
Ondersteunde Azure OpenAI-eindpunten (protocol en hostnaam, bijvoorbeeld: https://aoairesource.openai.azure.com. Vervang 'aoairesource' door uw Azure OpenAI-resourcenaam). https://{your-resource-name}.openai.azure.com |
| api-versie | zoekopdracht | No | De expliciete Foundry Models API-versie die voor deze aanvraag moet worden gebruikt.v1 als dit niet anders is opgegeven. |
Koptekst van aanvraag
Gebruik verificatie op basis van tokens of API-sleutel. Verificatie met verificatie op basis van tokens wordt aanbevolen en veiliger.
| Naam | Required | Type | Description |
|---|---|---|---|
| Autorisatie | True | tekenreeks |
Voorbeeld:Authorization: Bearer {Azure_OpenAI_Auth_Token}To genereer een verificatietoken met behulp van Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comType: oauth2 Autorisatie-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeScope: https://ai.azure.com/.default |
| API-sleutel | True | tekenreeks | Geef hier Azure OpenAI API-sleutel op |
Aanvraaglichaam
Inhoudstype: multipart/form-data
| Naam | Type | Description | Required | Default |
|---|---|---|---|---|
| bestand | tekenreeks | Ja | ||
| filename | tekenreeks | De optionele bestandsnaam of beschrijvende id die moet worden gekoppeld aan de audiogegevens | No | |
| model | tekenreeks | Het model dat moet worden gebruikt voor deze vertaalaanvraag. | No | |
| prompt | tekenreeks | Een optionele tekst om de stijl van het model te begeleiden of door te gaan met een vorig audiosegment. De prompt moet in het Engels zijn. | No | |
| responsformaat | Object | No | ||
| Temperatuur | number | De steekproeftemperatuur, tussen 0 en 1. Hogere waarden zoals 0,8 zorgen ervoor dat de uitvoer willekeuriger wordt, terwijl lagere waarden zoals 0,2 ervoor zorgen dat de uitvoer meer gericht en deterministisch wordt. Als dit is ingesteld op 0, gebruikt het model logboekkans om de temperatuur automatisch te verhogen totdat bepaalde drempelwaarden worden bereikt. | No | 0 |
Responses
Statuscode: 200
Beschrijving: De aanvraag is geslaagd.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureAudioTranslationResponse | |
| text/plain | tekenreeks |
Statuscode: standaard
Beschrijving: Een onverwachte foutreactie.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureErrorResponse |
Voorbeelden
Voorbeeld
Hiermee haalt u getranscribeerde engelse tekst en bijbehorende metagegevens op van opgegeven gesproken audiogegevens.
POST {endpoint}/openai/v1/audio/translations?api-version=preview
{
"file": "<binary audio data>",
"model": "whisper-1",
"response_format": "text"
}
Antwoorden: Statuscode: 200
{
"body": "plain text when requesting text, srt, or vtt"
}
Afbeeldingsbewerking maken
POST {endpoint}/openai/v1/images/edits?api-version=preview
URI-parameters
| Naam | In | Required | Type | Description |
|---|---|---|---|---|
| endpoint | path | Ja | tekenreeks URL |
Ondersteunde Azure OpenAI-eindpunten (protocol en hostnaam, bijvoorbeeld: https://aoairesource.openai.azure.com. Vervang 'aoairesource' door uw Azure OpenAI-resourcenaam). https://{your-resource-name}.openai.azure.com |
| api-versie | zoekopdracht | No | De expliciete Foundry Models API-versie die voor deze aanvraag moet worden gebruikt.v1 als dit niet anders is opgegeven. |
Koptekst van aanvraag
Gebruik verificatie op basis van tokens of API-sleutel. Verificatie met verificatie op basis van tokens wordt aanbevolen en veiliger.
| Naam | Required | Type | Description |
|---|---|---|---|
| Autorisatie | True | tekenreeks |
Voorbeeld:Authorization: Bearer {Azure_OpenAI_Auth_Token}To genereer een verificatietoken met behulp van Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comType: oauth2 Autorisatie-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeScope: https://ai.azure.com/.default |
| API-sleutel | True | tekenreeks | Geef hier Azure OpenAI API-sleutel op |
Aanvraaglichaam
Inhoudstype: multipart/form-data
| Naam | Type | Description | Required | Default |
|---|---|---|---|---|
| achtergrond | enum | Hiermee kunt u transparantie instellen voor de achtergrond van de gegenereerde installatiekopieën. Deze parameter wordt alleen ondersteund voor gpt-image-1 modellen. Moet een van transparent, opaque of auto (standaardwaarde) zijn. Wanneer auto het model wordt gebruikt, wordt automatisch de beste achtergrond voor de afbeelding bepaald.Als transparentde uitvoerindeling transparantie moet ondersteunen, moet deze worden ingesteld op png (standaardwaarde) of webp.Mogelijke waarden: transparent, opaqueauto |
No | |
| afbeelding | tekenreeks of matrix | Ja | ||
| mask | tekenreeks | No | ||
| model | tekenreeks | De modelimplementatie die moet worden gebruikt voor de bewerking voor het bewerken van afbeeldingen. | Ja | |
| n | integer | Het aantal afbeeldingen dat moet worden gegenereerd. Moet tussen 1 en 10 zijn. | No | 1 |
| uitvoercompressie | integer | Het compressieniveau (0-100%) voor de gegenereerde afbeeldingen. Deze parameter wordt alleen ondersteund voor gpt-image-1-series-modellen met de webp of jpeg uitvoerindelingen en wordt standaard ingesteld op 100. |
No | 100 |
| uitvoerformaat | enum | De indeling waarin de gegenereerde afbeeldingen worden geretourneerd. Deze parameter wordt alleen ondersteund voor gpt-image-1-series-modellen. Moet een van png, jpegof webp.De standaardwaarde is png.Mogelijke waarden: png, jpegwebp |
No | |
| prompt | tekenreeks | Een tekstbeschrijving van de gewenste afbeelding(en). De maximale lengte is 1000 tekens voor dall-e-2en 32000 tekens voor gpt-image-1-seriemodellen. |
Ja | |
| kwaliteit | enum | De kwaliteit van de afbeelding die wordt gegenereerd.
highen mediumlow worden alleen ondersteund voor gpt-image-1-series-modellen.
dall-e-2 ondersteunt standard alleen kwaliteit. Standaard ingesteld op auto.Mogelijke waarden: standard, low, medium, , highauto |
No | |
| responsformaat | enum | De indeling waarin de gegenereerde afbeeldingen worden geretourneerd. Moet een van url of b64_json. URL's zijn slechts 60 minuten geldig nadat de afbeelding is gegenereerd. Deze parameter wordt alleen ondersteund voor dall-e-2, omdat gpt-image-1-series-modellen altijd base64-gecodeerde afbeeldingen retourneren.Mogelijke waarden: url, b64_json |
No | |
| size | enum | De grootte van de gegenereerde afbeeldingen. Moet een van 1024x1024, 1536x1024 (liggend), 1024x1536 (staand) of auto (standaardwaarde) zijn voor gpt-image-1-seriemodellen, en een van 256x256, 512x512of 1024x1024 voor dall-e-2.Mogelijke waarden: 256x256, 512x512, 1024x1024, 1536x1024, , 1024x1536auto |
No | |
| user | tekenreeks | Een unieke id die uw eindgebruiker vertegenwoordigt, waarmee OpenAI misbruik kan bewaken en detecteren. | No |
Responses
Statuscode: 200
Beschrijving: De aanvraag is geslaagd.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureImagesResponse |
Statuscode: standaard
Beschrijving: Een onverwachte foutreactie.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureErrorResponse |
Createimage
POST {endpoint}/openai/v1/images/generations?api-version=preview
URI-parameters
| Naam | In | Required | Type | Description |
|---|---|---|---|---|
| endpoint | path | Ja | tekenreeks URL |
Ondersteunde Azure OpenAI-eindpunten (protocol en hostnaam, bijvoorbeeld: https://aoairesource.openai.azure.com. Vervang 'aoairesource' door uw Azure OpenAI-resourcenaam). https://{your-resource-name}.openai.azure.com |
| api-versie | zoekopdracht | No | De expliciete Foundry Models API-versie die voor deze aanvraag moet worden gebruikt.v1 als dit niet anders is opgegeven. |
Koptekst van aanvraag
Gebruik verificatie op basis van tokens of API-sleutel. Verificatie met verificatie op basis van tokens wordt aanbevolen en veiliger.
| Naam | Required | Type | Description |
|---|---|---|---|
| Autorisatie | True | tekenreeks |
Voorbeeld:Authorization: Bearer {Azure_OpenAI_Auth_Token}To genereer een verificatietoken met behulp van Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comType: oauth2 Autorisatie-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeScope: https://ai.azure.com/.default |
| API-sleutel | True | tekenreeks | Geef hier Azure OpenAI API-sleutel op |
Aanvraaglichaam
Inhoudstype: toepassing/json
| Naam | Type | Description | Required | Default |
|---|---|---|---|---|
| achtergrond | enum | Hiermee kunt u transparantie instellen voor de achtergrond van de gegenereerde installatiekopieën. Deze parameter wordt alleen ondersteund voor gpt-image-1 modellen. Moet een van transparent, opaque of auto (standaardwaarde) zijn. Wanneer auto het model wordt gebruikt, wordt automatisch de beste achtergrond voor de afbeelding bepaald.Als transparentde uitvoerindeling transparantie moet ondersteunen, moet deze worden ingesteld op png (standaardwaarde) of webp.Mogelijke waarden: transparent, opaqueauto |
No | |
| model | tekenreeks | De modelimplementatie die moet worden gebruikt voor het genereren van installatiekopieën. | Ja | |
| moderation | enum | Het inhoudsbeheerniveau beheren voor afbeeldingen die worden gegenereerd door gpt-image-1-seriemodellen. Moet voor minder beperkend filteren of low (standaardwaarde) zijnauto.Mogelijke waarden: low, auto |
No | |
| n | integer | Het aantal afbeeldingen dat moet worden gegenereerd. Moet tussen 1 en 10 zijn. Voor dall-e-3, wordt alleen n=1 ondersteund. |
No | 1 |
| uitvoercompressie | integer | Het compressieniveau (0-100%) voor de gegenereerde afbeeldingen. Deze parameter wordt alleen ondersteund voor gpt-image-1-series-modellen met de webp of jpeg uitvoerindelingen en wordt standaard ingesteld op 100. |
No | 100 |
| uitvoerformaat | enum | De indeling waarin de gegenereerde afbeeldingen worden geretourneerd. Deze parameter wordt alleen ondersteund voor gpt-image-1-series-modellen. Moet een van png, jpegof webp.Mogelijke waarden: png, jpegwebp |
No | |
| prompt | tekenreeks | Een tekstbeschrijving van de gewenste afbeelding(en). De maximale lengte is 32000 tekens voor gpt-image-1-seriemodellen, 1000 tekens voor dall-e-2 en 4000 tekens voor dall-e-3. |
Ja | |
| kwaliteit | enum | De kwaliteit van de afbeelding die wordt gegenereerd. - auto (standaardwaarde) selecteert automatisch de beste kwaliteit voor het opgegeven model.- highen mediumlow worden ondersteund voor gpt-image-1-series-modellen.- hd en standard worden ondersteund voor dall-e-3.- standard is de enige optie voor dall-e-2.Mogelijke waarden: standard, hd, low, medium, , highauto |
No | |
| responsformaat | enum | De indeling waarin gegenereerde afbeeldingen met dall-e-2 en dall-e-3 worden geretourneerd. Moet een van url of b64_json. URL's zijn slechts 60 minuten geldig nadat de afbeelding is gegenereerd. Deze parameter wordt niet ondersteund voor gpt-image-1-seriemodellen die altijd base64-gecodeerde afbeeldingen retourneren.Mogelijke waarden: url, b64_json |
No | |
| size | enum | De grootte van de gegenereerde afbeeldingen. Moet een van 1024x1024, 1536x1024 (liggend), 1024x1536 (staand) of auto (standaardwaarde) zijn voor gpt-image-1-seriemodellen, een van 256x256, 512x512of voor 1024x1024, en dall-e-2 een van 1024x1024, 1792x1024of 1024x1792 voor dall-e-3.Mogelijke waarden: auto, 1024x1024, 1536x1024, 1024x1536, 256x256, , 512x5121792x10241024x1792 |
No | |
| Stijl | enum | De stijl van de gegenereerde afbeeldingen. Deze parameter wordt alleen ondersteund voor dall-e-3. Moet een van vivid of natural. Levendig zorgt ervoor dat het model leunt op het genereren van hyper-echte en dramatische afbeeldingen. Natuurlijk zorgt ervoor dat het model natuurlijkere, minder hyper-echte afbeeldingen produceert.Mogelijke waarden: vivid, natural |
No | |
| user | tekenreeks | Een unieke id die uw eindgebruiker vertegenwoordigt, waarmee OpenAI misbruik kan bewaken en detecteren. | No |
Responses
Statuscode: 200
Beschrijving: De aanvraag is geslaagd.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureImagesResponse |
Statuscode: standaard
Beschrijving: Een onverwachte foutreactie.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureErrorResponse |
Voorbeelden
Voorbeeld
Hiermee maakt u installatiekopieën op basis van een prompt.
POST {endpoint}/openai/v1/images/generations?api-version=preview
{
"model": "dall-e-3",
"prompt": "In the style of WordArt, Microsoft Clippy wearing a cowboy hat.",
"n": 1,
"style": "natural",
"quality": "standard"
}
Antwoorden: Statuscode: 200
{
"body": {
"created": 1698342300,
"data": [
{
"revised_prompt": "A vivid, natural representation of Microsoft Clippy wearing a cowboy hat.",
"prompt_filter_results": {
"sexual": {
"severity": "safe",
"filtered": false
},
"violence": {
"severity": "safe",
"filtered": false
},
"hate": {
"severity": "safe",
"filtered": false
},
"self_harm": {
"severity": "safe",
"filtered": false
},
"profanity": {
"detected": false,
"filtered": false
},
"custom_blocklists": {
"filtered": false,
"details": []
}
},
"url": "https://dalletipusw2.blob.core.windows.net/private/images/e5451cc6-b1ad-4747-bd46-b89a3a3b8bc3/generated_00.png?se=2023-10-27T17%3A45%3A09Z&...",
"content_filter_results": {
"sexual": {
"severity": "safe",
"filtered": false
},
"violence": {
"severity": "safe",
"filtered": false
},
"hate": {
"severity": "safe",
"filtered": false
},
"self_harm": {
"severity": "safe",
"filtered": false
}
}
}
]
}
}
Taken voor het genereren van video's - Maken
POST {endpoint}/openai/v1/video/generations/jobs?api-version=preview
Hiermee maakt u een nieuwe taak voor het genereren van video's.
URI-parameters
| Naam | In | Required | Type | Description |
|---|---|---|---|---|
| endpoint | path | Ja | tekenreeks URL |
Ondersteunde Azure OpenAI-eindpunten (protocol en hostnaam, bijvoorbeeld: https://aoairesource.openai.azure.com. Vervang 'aoairesource' door uw Azure OpenAI-resourcenaam). https://{your-resource-name}.openai.azure.com |
| api-versie | zoekopdracht | No | De expliciete Foundry Models API-versie die voor deze aanvraag moet worden gebruikt.v1 als dit niet anders is opgegeven. |
Koptekst van aanvraag
Gebruik verificatie op basis van tokens of API-sleutel. Verificatie met verificatie op basis van tokens wordt aanbevolen en veiliger.
| Naam | Required | Type | Description |
|---|---|---|---|
| Autorisatie | True | tekenreeks |
Voorbeeld:Authorization: Bearer {Azure_OpenAI_Auth_Token}To genereer een verificatietoken met behulp van Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comType: oauth2 Autorisatie-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeScope: https://ai.azure.com/.default |
| API-sleutel | True | tekenreeks | Geef hier Azure OpenAI API-sleutel op |
Aanvraaglichaam
Inhoudstype: toepassing/json
| Naam | Type | Description | Required | Default |
|---|---|---|---|---|
| height | integer | De hoogte van de video. De volgende afmetingen worden ondersteund: 480x480, 854x480, 720x720, 1280x720, 1080x1080 en 1920x1080 in zowel liggende als staande standen. | Ja | |
| model | tekenreeks | De naam van de implementatie die voor deze aanvraag moet worden gebruikt. | Ja | |
| n_seconds | integer | De duur van de videogeneratietaak. Moet tussen 1 en 20 seconden zijn. | No | 5 |
| n_variants | integer | Het aantal video's dat moet worden gemaakt als varianten voor deze taak. Moet tussen 1 en 5 zijn. Kleinere afmetingen maken meer varianten mogelijk. | No | 1 |
| prompt | tekenreeks | De prompt voor deze videogeneratietaak. | Ja | |
| width | integer | De breedte van de video. De volgende afmetingen worden ondersteund: 480x480, 854x480, 720x720, 1280x720, 1080x1080 en 1920x1080 in zowel liggende als staande standen. | Ja |
Aanvraaglichaam
Inhoudstype: multipart/form-data
| Naam | Type | Description | Required | Default |
|---|---|---|---|---|
| files | gegevensreeks | Ja | ||
| height | integer | De hoogte van de video. De volgende afmetingen worden ondersteund: 480x480, 854x480, 720x720, 1280x720, 1080x1080 en 1920x1080 in zowel liggende als staande standen. | Ja | |
| inpaint_items | gegevensreeks | Optionele inpainting-items voor deze videogeneratietaak. | No | |
| model | tekenreeks | De naam van de implementatie die voor deze aanvraag moet worden gebruikt. | Ja | |
| n_seconds | integer | De duur van de videogeneratietaak. Moet tussen 1 en 20 seconden zijn. | No | 5 |
| n_variants | integer | Het aantal video's dat moet worden gemaakt als varianten voor deze taak. Moet tussen 1 en 5 zijn. Kleinere afmetingen maken meer varianten mogelijk. | No | 1 |
| prompt | tekenreeks | De prompt voor deze videogeneratietaak. | Ja | |
| width | integer | De breedte van de video. De volgende afmetingen worden ondersteund: 480x480, 854x480, 720x720, 1280x720, 1080x1080 en 1920x1080 in zowel liggende als staande standen. | Ja |
Responses
Statuscode: 200
Beschrijving: De aanvraag is geslaagd.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | VideoGenerationJob |
Statuscode: standaard
Beschrijving: Een onverwachte foutreactie.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Voorbeelden
Voorbeeldbestand is niet gevonden: ./examples/create_video_generation_job_simple.json
Taken voor het genereren van video's - Lijst
GET {endpoint}/openai/v1/video/generations/jobs?api-version=preview
Een lijst met taken voor het genereren van video's.
URI-parameters
| Naam | In | Required | Type | Description |
|---|---|---|---|---|
| endpoint | path | Ja | tekenreeks URL |
Ondersteunde Azure OpenAI-eindpunten (protocol en hostnaam, bijvoorbeeld: https://aoairesource.openai.azure.com. Vervang 'aoairesource' door uw Azure OpenAI-resourcenaam). https://{your-resource-name}.openai.azure.com |
| api-versie | zoekopdracht | No | De expliciete Foundry Models API-versie die voor deze aanvraag moet worden gebruikt.v1 als dit niet anders is opgegeven. |
|
| voordat | zoekopdracht | No | tekenreeks | |
| after | zoekopdracht | No | tekenreeks | |
| limit | zoekopdracht | Ja | integer | |
| statuses | zoekopdracht | No | gegevensreeks |
Koptekst van aanvraag
Gebruik verificatie op basis van tokens of API-sleutel. Verificatie met verificatie op basis van tokens wordt aanbevolen en veiliger.
| Naam | Required | Type | Description |
|---|---|---|---|
| Autorisatie | True | tekenreeks |
Voorbeeld:Authorization: Bearer {Azure_OpenAI_Auth_Token}To genereer een verificatietoken met behulp van Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comType: oauth2 Autorisatie-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeScope: https://ai.azure.com/.default |
| API-sleutel | True | tekenreeks | Geef hier Azure OpenAI API-sleutel op |
Responses
Statuscode: 200
Beschrijving: De aanvraag is geslaagd.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | VideoGenerationJobList |
Statuscode: standaard
Beschrijving: Een onverwachte foutreactie.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Voorbeelden
Voorbeeldbestand is niet gevonden: ./examples/get_video_generation_job_list.json
Taken voor het genereren van video's - Ophalen
GET {endpoint}/openai/v1/video/generations/jobs/{job-id}?api-version=preview
Hiermee worden eigenschappen van een videogeneratietaak opgehaald.
URI-parameters
| Naam | In | Required | Type | Description |
|---|---|---|---|---|
| endpoint | path | Ja | tekenreeks URL |
Ondersteunde Azure OpenAI-eindpunten (protocol en hostnaam, bijvoorbeeld: https://aoairesource.openai.azure.com. Vervang 'aoairesource' door uw Azure OpenAI-resourcenaam). https://{your-resource-name}.openai.azure.com |
| api-versie | zoekopdracht | No | De expliciete Foundry Models API-versie die voor deze aanvraag moet worden gebruikt.v1 als dit niet anders is opgegeven. |
|
| job-id | path | Ja | tekenreeks | De id van de taak voor het genereren van video's die moet worden gebruikt voor de Azure OpenAI-aanvraag. |
Koptekst van aanvraag
Gebruik verificatie op basis van tokens of API-sleutel. Verificatie met verificatie op basis van tokens wordt aanbevolen en veiliger.
| Naam | Required | Type | Description |
|---|---|---|---|
| Autorisatie | True | tekenreeks |
Voorbeeld:Authorization: Bearer {Azure_OpenAI_Auth_Token}To genereer een verificatietoken met behulp van Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comType: oauth2 Autorisatie-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeScope: https://ai.azure.com/.default |
| API-sleutel | True | tekenreeks | Geef hier Azure OpenAI API-sleutel op |
Responses
Statuscode: 200
Beschrijving: De aanvraag is geslaagd.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | VideoGenerationJob |
Statuscode: standaard
Beschrijving: Een onverwachte foutreactie.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Voorbeelden
Voorbeeldbestand is niet gevonden: ./examples/get_video_generation_job.json
Taken voor het genereren van video's - Verwijderen
DELETE {endpoint}/openai/v1/video/generations/jobs/{job-id}?api-version=preview
Hiermee verwijdert u een taak voor het genereren van video's.
URI-parameters
| Naam | In | Required | Type | Description |
|---|---|---|---|---|
| endpoint | path | Ja | tekenreeks URL |
Ondersteunde Azure OpenAI-eindpunten (protocol en hostnaam, bijvoorbeeld: https://aoairesource.openai.azure.com. Vervang 'aoairesource' door uw Azure OpenAI-resourcenaam). https://{your-resource-name}.openai.azure.com |
| api-versie | zoekopdracht | No | De expliciete Foundry Models API-versie die voor deze aanvraag moet worden gebruikt.v1 als dit niet anders is opgegeven. |
|
| job-id | path | Ja | tekenreeks | De id van de taak voor het genereren van video's die moet worden gebruikt voor de Azure OpenAI-aanvraag. |
Koptekst van aanvraag
Gebruik verificatie op basis van tokens of API-sleutel. Verificatie met verificatie op basis van tokens wordt aanbevolen en veiliger.
| Naam | Required | Type | Description |
|---|---|---|---|
| Autorisatie | True | tekenreeks |
Voorbeeld:Authorization: Bearer {Azure_OpenAI_Auth_Token}To genereer een verificatietoken met behulp van Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comType: oauth2 Autorisatie-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeScope: https://ai.azure.com/.default |
| API-sleutel | True | tekenreeks | Geef hier Azure OpenAI API-sleutel op |
Responses
Statuscode: 204
Beschrijving: Er is geen inhoud die voor deze aanvraag moet worden verzonden, maar de headers kunnen nuttig zijn.
Statuscode: standaard
Beschrijving: Een onverwachte foutreactie.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Videogeneraties - Get
GET {endpoint}/openai/v1/video/generations/{generation-id}?api-version=preview
Hiermee haalt u een videogeneratie op id op.
URI-parameters
| Naam | In | Required | Type | Description |
|---|---|---|---|---|
| endpoint | path | Ja | tekenreeks URL |
Ondersteunde Azure OpenAI-eindpunten (protocol en hostnaam, bijvoorbeeld: https://aoairesource.openai.azure.com. Vervang 'aoairesource' door uw Azure OpenAI-resourcenaam). https://{your-resource-name}.openai.azure.com |
| api-versie | zoekopdracht | No | De expliciete Foundry Models API-versie die voor deze aanvraag moet worden gebruikt.v1 als dit niet anders is opgegeven. |
|
| generation-id | path | Ja | tekenreeks | De id van de videogeneratie die moet worden gebruikt voor de Azure OpenAI-aanvraag. |
Koptekst van aanvraag
Gebruik verificatie op basis van tokens of API-sleutel. Verificatie met verificatie op basis van tokens wordt aanbevolen en veiliger.
| Naam | Required | Type | Description |
|---|---|---|---|
| Autorisatie | True | tekenreeks |
Voorbeeld:Authorization: Bearer {Azure_OpenAI_Auth_Token}To genereer een verificatietoken met behulp van Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comType: oauth2 Autorisatie-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeScope: https://ai.azure.com/.default |
| API-sleutel | True | tekenreeks | Geef hier Azure OpenAI API-sleutel op |
Responses
Statuscode: 200
Beschrijving: De aanvraag is geslaagd.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | VideoGeneration |
Statuscode: standaard
Beschrijving: Een onverwachte foutreactie.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Voorbeelden
Voorbeeldbestand is niet gevonden: ./examples/get_video_generation.json
Videogeneraties - Miniatuur ophalen
GET {endpoint}/openai/v1/video/generations/{generation-id}/content/thumbnail?api-version=preview
Hiermee haalt u een miniatuur van de gegenereerde video-inhoud op.
URI-parameters
| Naam | In | Required | Type | Description |
|---|---|---|---|---|
| endpoint | path | Ja | tekenreeks URL |
Ondersteunde Azure OpenAI-eindpunten (protocol en hostnaam, bijvoorbeeld: https://aoairesource.openai.azure.com. Vervang 'aoairesource' door uw Azure OpenAI-resourcenaam). https://{your-resource-name}.openai.azure.com |
| api-versie | zoekopdracht | No | De expliciete Foundry Models API-versie die voor deze aanvraag moet worden gebruikt.v1 als dit niet anders is opgegeven. |
|
| generation-id | path | Ja | tekenreeks | De id van de videogeneratie die moet worden gebruikt voor de Azure OpenAI-aanvraag. |
Koptekst van aanvraag
Gebruik verificatie op basis van tokens of API-sleutel. Verificatie met verificatie op basis van tokens wordt aanbevolen en veiliger.
| Naam | Required | Type | Description |
|---|---|---|---|
| Autorisatie | True | tekenreeks |
Voorbeeld:Authorization: Bearer {Azure_OpenAI_Auth_Token}To genereer een verificatietoken met behulp van Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comType: oauth2 Autorisatie-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeScope: https://ai.azure.com/.default |
| API-sleutel | True | tekenreeks | Geef hier Azure OpenAI API-sleutel op |
Responses
Statuscode: 200
Beschrijving: De aanvraag is geslaagd.
| Inhoudstype | Typ | Description |
|---|---|---|
| afbeelding/jpg | tekenreeks |
Statuscode: standaard
Beschrijving: Een onverwachte foutreactie.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Videogeneraties - Video-inhoud ophalen
GET {endpoint}/openai/v1/video/generations/{generation-id}/content/video?api-version=preview
Haalt de gegenereerde video-inhoud op.
URI-parameters
| Naam | In | Required | Type | Description |
|---|---|---|---|---|
| endpoint | path | Ja | tekenreeks URL |
Ondersteunde Azure OpenAI-eindpunten (protocol en hostnaam, bijvoorbeeld: https://aoairesource.openai.azure.com. Vervang 'aoairesource' door uw Azure OpenAI-resourcenaam). https://{your-resource-name}.openai.azure.com |
| api-versie | zoekopdracht | No | De expliciete Foundry Models API-versie die voor deze aanvraag moet worden gebruikt.v1 als dit niet anders is opgegeven. |
|
| generation-id | path | Ja | tekenreeks | De id van de videogeneratie die moet worden gebruikt voor de Azure OpenAI-aanvraag. |
| kwaliteit | zoekopdracht | No |
Koptekst van aanvraag
Gebruik verificatie op basis van tokens of API-sleutel. Verificatie met verificatie op basis van tokens wordt aanbevolen en veiliger.
| Naam | Required | Type | Description |
|---|---|---|---|
| Autorisatie | True | tekenreeks |
Voorbeeld:Authorization: Bearer {Azure_OpenAI_Auth_Token}To genereer een verificatietoken met behulp van Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comType: oauth2 Autorisatie-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeScope: https://ai.azure.com/.default |
| API-sleutel | True | tekenreeks | Geef hier Azure OpenAI API-sleutel op |
Responses
Statuscode: 200
Beschrijving: De aanvraag is geslaagd.
| Inhoudstype | Typ | Description |
|---|---|---|
| video/mp4 | tekenreeks |
Statuscode: standaard
Beschrijving: Een onverwachte foutreactie.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Videogeneraties - Alleen videocontent-headers ophalen
HEAD {endpoint}/openai/v1/video/generations/{generation-id}/content/video?api-version=preview
Haalt headers op voor de gegenereerde video-inhoud.
URI-parameters
| Naam | In | Required | Type | Description |
|---|---|---|---|---|
| endpoint | path | Ja | tekenreeks URL |
Ondersteunde Azure OpenAI-eindpunten (protocol en hostnaam, bijvoorbeeld: https://aoairesource.openai.azure.com. Vervang 'aoairesource' door uw Azure OpenAI-resourcenaam). https://{your-resource-name}.openai.azure.com |
| api-versie | zoekopdracht | No | De expliciete Foundry Models API-versie die voor deze aanvraag moet worden gebruikt.v1 als dit niet anders is opgegeven. |
|
| generation-id | path | Ja | tekenreeks | De id van de videogeneratie die moet worden gebruikt voor de Azure OpenAI-aanvraag. |
| kwaliteit | zoekopdracht | No |
Koptekst van aanvraag
Gebruik verificatie op basis van tokens of API-sleutel. Verificatie met verificatie op basis van tokens wordt aanbevolen en veiliger.
| Naam | Required | Type | Description |
|---|---|---|---|
| Autorisatie | True | tekenreeks |
Voorbeeld:Authorization: Bearer {Azure_OpenAI_Auth_Token}To genereer een verificatietoken met behulp van Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comType: oauth2 Autorisatie-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeScope: https://ai.azure.com/.default |
| API-sleutel | True | tekenreeks | Geef hier Azure OpenAI API-sleutel op |
Responses
Statuscode: 200
Beschrijving: De aanvraag is geslaagd.
Statuscode: standaard
Beschrijving: Een onverwachte foutreactie.
| Inhoudstype | Typ | Description |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Components
Zie de naslaginformatie over de Azure OpenAI REST API voor de schemadefinities die worden gebruikt door chatten, voltooiingen, insluitingen, antwoorden en andere tekstbewerkingen. De volgende schema's ondersteunen de bewerkingen voor afbeeldingen, audio en video op deze pagina.
AzureAudioTranscriptionResponse
Resultaatinformatie voor een bewerking waarmee gesproken audio in geschreven tekst is getranscribeerd.
| Naam | Type | Description | Required | Default |
|---|---|---|---|---|
| duration | number | De totale duur van de audio die is verwerkt om bijbehorende transcriptiegegevens te produceren. | No | |
| language | tekenreeks | De gesproken taal die is gedetecteerd in de getranscribeerde audiogegevens. Dit wordt uitgedrukt als een ISO-639-1-taalcode van twee letters, zoals 'en' of 'fr'. |
No | |
| segments | gegevensreeks | Een verzameling informatie over de timing, waarschijnlijkheden en andere details van elk verwerkt audiosegment. | No | |
| taak | Object | Definieert de mogelijke descriptors voor beschikbare antwoorden voor audiobewerkingen. | No | |
| tekst | tekenreeks | De getranscribeerde tekst voor de opgegeven audiogegevens. | Ja | |
| words | gegevensreeks | Een verzameling informatie over de timing van elk verwerkt woord. | No |
AzureAudioTranslationResponse
Resultaatinformatie voor een bewerking waarmee gesproken audio in geschreven tekst is vertaald.
| Naam | Type | Description | Required | Default |
|---|---|---|---|---|
| duration | number | De totale duur van de audio die is verwerkt voor het produceren van begeleidende vertaalgegevens. | No | |
| language | tekenreeks | De gesproken taal die is gedetecteerd in de vertaalde audiogegevens. Dit wordt uitgedrukt als een ISO-639-1-taalcode van twee letters, zoals 'en' of 'fr'. |
No | |
| segments | gegevensreeks | Een verzameling informatie over de timing, waarschijnlijkheden en andere details van elk verwerkt audiosegment. | No | |
| taak | Object | Definieert de mogelijke descriptors voor beschikbare antwoorden voor audiobewerkingen. | No | |
| tekst | tekenreeks | De vertaalde tekst voor de opgegeven audiogegevens. | Ja |
AzureErrorResponse
| Naam | Type | Description | Required | Default |
|---|---|---|---|---|
| error | Object | De foutdetails. | No | |
| └* code | tekenreeks | De unieke, door de machine gegenereerde id voor de fout. | No | |
| └─inner_error | No | |||
| └• bericht | tekenreeks | Een door mensen leesbaar bericht dat aan de fout is gekoppeld. | No | |
| └* param | tekenreeks | Indien van toepassing, de aanvraaginvoerparameter die is gekoppeld aan de fout | No | |
| └type. | enum | Het objecttype, altijd 'error'. Mogelijke waarden: error |
No |
AzureImagesResponse
| Naam | Type | Description | Required | Default |
|---|---|---|---|---|
| achtergrond | enum | ALLEEN GPT-image-1: de achtergrondparameter die wordt gebruikt voor het genereren van de installatiekopieën.
transparentOf opaque .Mogelijke waarden: transparent, opaque |
No | |
| created | integer | De Unix-tijdstempel (in seconden) van het moment waarop de installatiekopieën zijn gemaakt. | Ja | |
| Gegevens | gegevensreeks | No | ||
| uitvoerformaat | enum | De uitvoerindeling van de generatie van de installatiekopieën. Ofwel png, webpof jpeg.Mogelijke waarden: png, webpjpeg |
No | |
| kwaliteit | enum | De kwaliteit van de gegenereerde afbeelding. Ofwel low, mediumof high.Mogelijke waarden: low, mediumhigh |
No | |
| size | enum | De grootte van de gegenereerde installatiekopieën. Ofwel 1024x1024, 1024x1536of 1536x1024.Mogelijke waarden: 1024x1024, 1024x15361536x1024 |
No | |
| gebruik | Object | Alleen voor gpt-image-1modellen uit de reeks worden de gebruiksgegevens van het token voor het genereren van de installatiekopieën gebruikt. |
No | |
| └input_tokens | integer | Het aantal tokens (afbeeldingen en tekst) in de invoerprompt. | No | |
| └─input_tokens_details | Object | De invoertokens gedetailleerde informatie voor het genereren van afbeeldingen. | No | |
| └image_tokens | integer | Het aantal afbeeldingstokens in de invoerprompt. | No | |
| └text_tokens | integer | Het aantal teksttokens in de invoerprompt. | No | |
| └output_tokens | integer | Het aantal installatiekopieën in de uitvoerafbeelding. | No | |
| └ totaal tokens | integer | Het totale aantal tokens (afbeeldingen en tekst) dat wordt gebruikt voor het genereren van afbeeldingen. | No |
AzureOpenAIVideoGenerationErrorResponse
| Naam | Type | Description | Required | Default |
|---|---|---|---|---|
| code | tekenreeks | De unieke, door de machine gegenereerde id voor de fout. | No | |
| inner_error | Object | Indien van toepassing, een upstream-fout die deze fout heeft veroorzaakt. | No | |
| └* code | enum | De code die is gekoppeld aan de interne fout. Mogelijke waarden: ResponsibleAIPolicyViolation |
No | |
| └error_details | De details van het inhoudsfilterresultaat die zijn gekoppeld aan de interne fout. | No | ||
| └revised_prompt | tekenreeks | Indien van toepassing, wordt de wijzigingsprompt gebruikt voor het genereren. | No | |
| message | tekenreeks | Een door mensen leesbaar bericht dat aan de fout is gekoppeld. | No | |
| param | tekenreeks | Indien van toepassing, de aanvraaginvoerparameter die is gekoppeld aan de fout | No | |
| type | tekenreeks | Indien van toepassing, is het nummer van de invoerregel gekoppeld aan de fout. | No |
VideoGeneration
Een resultaat voor het genereren van video's.
| Naam | Type | Description | Required | Default |
|---|---|---|---|---|
| aangemaakt_op | integer | Het tijdstip waarop de videogeneratie is gemaakt. | Ja | |
| height | integer | De hoogte van de video. | Ja | |
| identiteitskaart | tekenreeks | De id van de videogeneratie. | Ja | |
| job_id | tekenreeks | De id van de taak voor het genereren van video's voor deze video. | Ja | |
| n_seconds | integer | De duur van de videogeneratie. | Ja | |
| Object | enum | Mogelijke waarden: video.generation |
Ja | |
| prompt | tekenreeks | De prompt voor deze videogeneratie. | Ja | |
| width | integer | De breedte van de video. | Ja |
VideoGenerationJob
Een videogeneratietaak.
| Naam | Type | Description | Required | Default |
|---|---|---|---|---|
| aangemaakt_op | integer | Het tijdstip waarop de taak is gemaakt. | Ja | |
| verloopt_op | integer | Het tijdstip waarop de taak automatisch uit de service wordt verwijderd. De video-inhoud en metagegevens van de taak moeten vóór deze datum worden opgeslagen om gegevensverlies te voorkomen. | No | |
| failure_reason | tekenreeks (zie geldige modellen hieronder) | No | ||
| afgerond_op | integer | Het tijdstip waarop de taak klaar is met alle videogeneraties. | No | |
| Generaties | gegevensreeks | De gegenereerde video's voor deze taak. Het getal hangt af van de gegeven n_variants en het succes van de generaties. | No | |
| height | integer | De hoogte van de video. | Ja | |
| identiteitskaart | tekenreeks | De id van de taak. | Ja | |
| inpaint_items | gegevensreeks | Optionele inpainting-items voor deze videogeneratietaak. | No | |
| model | tekenreeks | De naam van de implementatie die moet worden gebruikt voor deze videogeneratietaak. | Ja | |
| n_seconds | integer | De duur van de videogeneratietaak. | Ja | |
| n_variants | integer | Het aantal video's dat moet worden gemaakt als varianten voor deze videogeneratietaak. | Ja | |
| Object | enum | Mogelijke waarden: video.generation.job |
Ja | |
| prompt | tekenreeks | De prompt voor deze videogeneratietaak. | Ja | |
| status | Object | De status van een videogeneratietaak. | Ja | |
| width | integer | De hoogte van de video. | Ja |
VideoGenerationJobList
Een lijst met taken voor het genereren van video's.
| Naam | Type | Description | Required | Default |
|---|---|---|---|---|
| Gegevens | gegevensreeks | De lijst met taken voor het genereren van video's. | Ja | |
| first_id | tekenreeks | De id van de eerste taak op de huidige pagina, indien beschikbaar. | No | |
| heeft_meer | boolean | Een vlag die aangeeft of er meer taken beschikbaar zijn na de lijst. | Ja | |
| last_id | tekenreeks | De id van de laatste taak op de huidige pagina, indien beschikbaar. | No | |
| Object | enum | Mogelijke waarden: list |
Ja |
Volgende stappen
Meer informatie over modellen en afstemming met de REST API. Meer informatie over de onderliggende modellen die gebruikmaken van Azure OpenAI.